"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createResolvers = void 0;
const relay_1 = require("../relay");
const graphgen_to_graphql_1 = require("./graphgen-to-graphql");
const assert_ts_1 = require("assert-ts");
function createResolvers({ users, githubRepositories, githubOrganizations, }) {
    return {
        Query: {
            viewer(_, { size, cursor }) {
                let orgs = [...users]
                    .flatMap((e) => { var _a; return (_a = e.githubAccount) === null || _a === void 0 ? void 0 : _a.organizations; })
                    .flatMap((org) => (!!org ? [org] : []));
                return {
                    organizations: (0, relay_1.applyRelayPagination)(orgs, { first: size, after: cursor }, (org) => (0, graphgen_to_graphql_1.toGraphql)(org)),
                };
            },
            organization(_, { login }) {
                let [org] = [...githubOrganizations].filter((o) => o.login === login);
                (0, assert_ts_1.assert)(!!org, `no organization found for ${login}`);
                return (0, graphgen_to_graphql_1.toGraphql)(org);
            },
            organizations(pageArgs) {
                let orgs = [...githubOrganizations];
                return (0, relay_1.applyRelayPagination)(orgs, pageArgs, (org) => (0, graphgen_to_graphql_1.toGraphql)(org));
            },
            repository(_, { owner, name }) {
                let repo = [...githubRepositories].find((r) => r.name.toLowerCase() === name &&
                    r.nameWithOwner.toLowerCase() === `${owner}/${name}`.toLowerCase());
                (0, assert_ts_1.assert)(!!repo, `no repository found for ${name}`);
                return (0, graphgen_to_graphql_1.toGraphql)(repo);
            },
            repositoryOwner(_, { login }) {
                let [org] = [...githubOrganizations].filter((o) => o.login === login);
                if (org)
                    return (0, graphgen_to_graphql_1.toGraphql)(org);
                let [userAccount] = [...users].filter((u) => u.githubAccount.login === login);
                (0, assert_ts_1.assert)(!!userAccount, `no github organization or account found for ${login}`);
                if (userAccount)
                    return (0, graphgen_to_graphql_1.toGraphql)(userAccount.githubAccount);
            },
        },
    };
}
exports.createResolvers = createResolvers;
//# sourceMappingURL=resolvers.js.map