import { applyRelayPagination } from '../relay';
import { toGraphql } from './graphgen-to-graphql';
import { assert } from 'assert-ts';
export function createResolvers({ users, githubRepositories, githubOrganizations, }) {
    return {
        Query: {
            viewer(_, { size, cursor }) {
                let orgs = [...users]
                    .flatMap((e) => e.githubAccount?.organizations)
                    .flatMap((org) => (!!org ? [org] : []));
                return {
                    organizations: applyRelayPagination(orgs, { first: size, after: cursor }, (org) => toGraphql(org)),
                };
            },
            organization(_, { login }) {
                let [org] = [...githubOrganizations].filter((o) => o.login === login);
                assert(!!org, `no organization found for ${login}`);
                return toGraphql(org);
            },
            organizations(pageArgs) {
                let orgs = [...githubOrganizations];
                return applyRelayPagination(orgs, pageArgs, (org) => toGraphql(org));
            },
            repository(_, { owner, name }) {
                let repo = [...githubRepositories].find((r) => r.name.toLowerCase() === name &&
                    r.nameWithOwner.toLowerCase() === `${owner}/${name}`.toLowerCase());
                assert(!!repo, `no repository found for ${name}`);
                return toGraphql(repo);
            },
            repositoryOwner(_, { login }) {
                let [org] = [...githubOrganizations].filter((o) => o.login === login);
                if (org)
                    return toGraphql(org);
                let [userAccount] = [...users].filter((u) => u.githubAccount.login === login);
                assert(!!userAccount, `no github organization or account found for ${login}`);
                if (userAccount)
                    return toGraphql(userAccount.githubAccount);
            },
        },
    };
}
//# sourceMappingURL=resolvers.js.map